<?php

/**
 * Data Access Object for `skeleton_record` table.
 *
 * @package ow.plugin.skeleton.bol
 * @since 1.0
 */
class CCONVO_BOL_RecordDao extends OW_BaseDao
{

    /**
     * Singleton instance.
     *
     * @var CCONVO_BOL_RecordDao
     */
    private static $classInstance;

    /**
     * Returns an instance of class (singleton pattern implementation).
     *
     * @return CCONVO_BOL_RecordDao
     */
    public static function getInstance()
    {
        if ( self::$classInstance === null )
        {
            self::$classInstance = new self();
        }

        return self::$classInstance;
    }

    /**
     * @see OW_BaseDao::getDtoClassName()
     *
     */
    public function getDtoClassName()
    {
        return 'CCONVO_BOL_Record';
    }

    /**
     * @see OW_BaseDao::getTableName()
     *
     */
    public function getTableName()
    {
        return OW_DB_PREFIX . 'cconvo_colleges';
    }

    /**
     * 
     * @return array
     */
    public function findResultList($data)
    {
		$name = $data['name'];
		$majors = $data['majors'];
		$sport = $data['clubSport'];
		$falculty = (int)$data['studentFacultyRatio'];
		$tuition = (int)$data['inStateTuition'];
		$students = (int)$data['fullTimeUndergrads'];
		$setting = $data['setting'];
		
		$totalStudents = '(fullTimeUndergrads + partTimeUndergrads)';
		
		$setting = ($setting && $setting != 'all') ? "AND setting LIKE '%$setting%'" : '';
		
		switch($tuition){
			case 0:
				$tuition = '';
				break;
			case 1:
				$tuition = "AND inStateTuition < 10000";
				break;
			case 2:
				$tuition = "AND inStateTuition >= 10000 AND inStateTuition <= 20000";
				break;
			case 3:
				$tuition = "AND inStateTuition >= 20000 AND inStateTuition <= 30000";
				break;
			case 4:
				$tuition = "AND inStateTuition >= 30000";
				break;
			default:
				$tuition = '';
		}
		
		switch($students){
			case 0:
				$students = '';
				break;
			case 1:
				$students = "AND $totalStudents < 5000";
				break;
			case 2:
				$students = "AND $totalStudents >= 5000 AND $totalStudents <= 10000";
				break;
			case 3:
				$students = "AND $totalStudents >= 10000 AND $totalStudents <= 20000";
				break;
			case 4:
				$students = "AND $totalStudents >= 20000";
				break;
			default:
				$students = '';
		}
		
		switch($falculty){
			case 0:
				$falculty = '';
				break;
			case 1:
				$falculty = "AND studentFacultyRatio < 10.1";
				break;
			case 2:
				$falculty = "AND studentFacultyRatio >= 10.1 AND studentFacultyRatio <= 20.1";
				break;
			case 3:
				$falculty = "AND $totalStudents >= 20.1";
				break;
			default:
				$falculty = '';
		}
		
		$query = "
			SELECT * 
			FROM `{$this->getTableName()}`
			WHERE name LIKE '%$name%'
			AND majors LIKE '%$majors%'
			AND clubSport LIKE '%$sport%'
			$setting
			$students
			$falculty
			$tuition
			ORDER BY `id` DESC
		";
         return $this->dbo->queryForObjectList($query, $this->getDtoClassName());
    }

    /**
     * 
     * @return array
     */
    public function findResultById($id)
    {
        $example = new OW_Example();
        $example->andFieldEqual('id', $id);
        
        return $this->findListByExample($example);
    }
}