<?php

class CCONVO_CTRL_Search extends OW_ActionController
{
    private $service;
    private $language;

    public function __construct()
    {
        $this->service = CCONVO_BOL_Service::getInstance();
        $this->language = OW::getLanguage();
		
		OW::getNavigation()->activateMenuItem(OW_Navigation::MAIN, 'cconvo', 'search_colleges');
        
        OW::getDocument()->setTitle($this->language->text("cconvo", "search_index_title"));
        OW::getDocument()->setHeading($this->language->text("cconvo", "search_index_heading"));
    }
	
    public function index()
    {
        $form = new CCONVO_CLASS_Form("cconvo_colleges");
        $form->setAction(OW::getRouter()->urlForRoute('cconvo.college_search_result'));
		$this->addForm($form);
		$form->setMethod(Form::METHOD_POST);
    }

    public function result()
    {
		$form = new CCONVO_CLASS_Form("cconvo_colleges");
		$tplList = array();
        
        if ( OW::getRequest()->isPost() && $form->isValid($_POST) )
        {
            $values = $form->getValues();
			$form->getElement('name')->setValue($values['name']);
			$form->getElement('majors')->setValue($values['majors']);
			$form->getElement('studentFacultyRatio')->setValue($values['studentFacultyRatio']);
			$form->getElement('clubSport')->setValue($values['clubSport']);
			$form->getElement('fullTimeUndergrads')->setValue($values['fullTimeUndergrads']);
			$form->getElement('inStateTuition')->setValue($values['inStateTuition']);
			$form->getElement('setting')->setValue($values['setting']);
        
			$list = $this->service->findResultList($values);
			foreach ( $list as $listItem )
			{
				/* @var $listItem CCONVO_BOL_Record */
				$tplList[] = array(
					"name" => $listItem->name,
					"address" => $listItem->address,
					"setting" => $listItem->setting,
					"url" => OW::getRouter()->urlForRoute('cconvo.college_search_result_item', array('id'=>$listItem->getId()))
				);
			}
            
        }
			
		$this->assign("list", $tplList);
        
        $this->addForm($form);
    }

    public function item($params)
    {
		$id = $params['id'];
		
		$list = $this->service->findResultById($id);
		$tplList = array();
		foreach ( $list as $listItem )
		{
			OW::getDocument()->setTitle($listItem->name);
			OW::getDocument()->setHeading($listItem->name);
			
			$totalStudents = (int)$listItem->maleUndergrads + (int)$listItem->femaleUndergrads;
			
			$maleRatio = ((int)$listItem->maleUndergrads / $totalStudents) * 100/1;
			$maleRatio = number_format((float)$maleRatio, 2, '.', '%');
			
			$femaleRatio = ((int)$listItem->femaleUndergrads / $totalStudents) * 100/1;
			$femaleRatio = number_format((float)$femaleRatio, 2, '.', '%');
			
			/* @var $listItem CCONVO_BOL_Record */
			$tplList[] = array(
				"name" => $listItem->name,
				"majors" => str_replace(",", "<br />", $listItem->majors),
				"clubSport" => $listItem->clubSport,
				"pageLink" => $listItem->pageLink,
				"address" => str_replace(",", "<br />", $listItem->address),
				"admissionEmail" => $listItem->admissionEmail,
				"phone" => $listItem->phone,
				"studentDiversity" => $listItem->studentDiversity,
				"athleticDivision" => $listItem->athleticDivision,
				"fullTimeUndergrads" => $listItem->fullTimeUndergrads,
				"partTimeUndergrads" => $listItem->partTimeUndergrads,
				"totalStudents" =>number_format($totalStudents),
				"maleRatio" =>$maleRatio,
				"femaleRatio" =>$femaleRatio,
				"maleUndergrads" => $listItem->maleUndergrads,
				"femaleUndergrads" => $listItem->femaleUndergrads,
				"applicationFee" => '$' . number_format((float)$listItem->applicationFee, 2, '.', ''),
				"studentFacultyRatio" => str_replace(".", ":", $listItem->studentFacultyRatio),
				"classSizes" => $listItem->classSizes,
				"acceptanceRate" => $listItem->acceptanceRate .'%',
				"inStateTuition" => '$'. number_format($listItem->inStateTuition),
				"outOfStateTuition" => '$'. number_format($listItem->outOfStateTuition),
				"roomBoard" => number_format((int)$listItem->roomBoard),
				"setting" => $listItem->setting,
				"menSport" => $listItem->menSport,
				"womenSport" => $listItem->womenSport,
				"intramurals" => $listItem->intramurals,
				"fraternities" => $listItem->fraternities,
				"sororities" => $listItem->sororities,
				"female_undergrads_1" => $listItem->female_undergrads_1,
				"male_undergrads_1" => $listItem->male_undergrads_1,
				"url" => OW::getRouter()->urlForRoute('cconvo.college_search_result_item', array('id'=>$listItem->getId()))
			);
		}
			
		$this->assign("list", $tplList);
    }

}